function eta = etanu( norm_r, norm_Atr, norm_AAtr, nu)
%ETANU error estimate for a set of approximate solutions (general case)
%
%   e = etanu(norm_r,norm_Atr,norm_AAtr,nu) computes the error estimate for a
%   set of solutions (x(:,i),i=1,...,k) of a linear system.
%
%   The input parameters norm_r, norm_Atr and norm_AAtr are k-vectors such that
%	norm_r(i) = norm(r(:,i)), where r(:,i)=b-A*x(:,i)
%	norm_Atr(i) = norm(A'*r(:,i))
%	norm_AAtr(i) = norm(A*A'*r(:,i))
%   nu is the index of the estimate (real number, default 3).
%
%   See also etanutik, enu, ehatnu, enutik.

% This function computes the estimates eta_nu defined in eq. (2.6) of the paper
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for the regularization of least squares problems.
%   Numer. Algorithms, 2009. In press. 

%	Giuseppe Rodriguez,  12-05-08
% 	Email: rodriguez@unica.it

if nargin < 4,  nu = 3;  end
eta = (norm_r.^(nu-1)) .* (norm_Atr.^(5-2*nu)) .* (norm_AAtr.^(nu-3));

